package com.weather.controller;


import com.weather.common.AjaxResult;
import com.weather.common.BaseController;
import com.weather.common.page.TableDataInfo;
import com.weather.entity.SysNotice;
import com.weather.service.ISysNoticeService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 公告 信息操作处理
 *
 * @author weather
 */
@RestController
@RequestMapping("/notice")
public class SysNoticeController extends BaseController
{
    @Autowired
    private ISysNoticeService noticeService;

    /**
     * 获取通知公告列表
     */
    @ApiOperation(value = "获取通知公告列表")
    @GetMapping("/list")
    public TableDataInfo list(SysNotice notice)
    {
        startPage();
        List<SysNotice> list = noticeService.selectNoticeList(notice);
        return getDataTable(list);
    }

    /**
     * 根据通知公告编号获取详细信息
     */
    @ApiOperation(value = "根据编号获取详细信息")
    @GetMapping(value = "/{noticeId}")
    public AjaxResult getInfo(@PathVariable Long noticeId)
    {
        return success(noticeService.selectNoticeById(noticeId));
    }

    /**
     * 新增通知公告
     */

    @ApiOperation(value = "新增通知公告")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysNotice notice)
    {

        return toAjax(noticeService.insertNotice(notice));
    }

    /**
     * 修改通知公告
     */

    @ApiOperation(value = "修改通知公告")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysNotice notice)
    {

        return toAjax(noticeService.updateNotice(notice));
    }

    /**
     * 删除通知公告
     */

    @ApiOperation(value = "删除通知公告")
    @DeleteMapping("/{noticeIds}")
    public AjaxResult remove(@PathVariable Long[] noticeIds)
    {
        return toAjax(noticeService.deleteNoticeByIds(noticeIds));
    }
}
